==> WymEditor.1.1.4.zip: WymEditor/WymEditor.php <==
<?php
/**
 * Plugin WymEditor for Pluxml
 *
 * @package	WymEditor
 * @version	1.1.4
 * @date	22.12.2018
 * @author	Thomas Ingles, sudwebdesign.free.fr
 **/
class WymEditor extends plxPlugin {
 public function __construct($default_lang){
  parent::__construct($default_lang);
  if(defined('PLX_ADMIN')) {//Déclaration des hooks pour la zone d'administration
   if(strstr($_SERVER['PHP_SELF'],'article.php') || strstr($_SERVER['QUERY_STRING'],'plxMyShop&prod')){//edit art ou prod slmnt ::: strstr($_SERVER['PHP_SELF'],'statique.php') ||
    $this->addHook('plxAdminEditArticleXml', 'plxAdminEditArticleXml');
    $this->addHook('plxAdminEditArticle', 'plxAdminEditArticle');
    $this->addHook('AdminArticleTop', 'AdminArticleTop');

    $this->addHook('AdminTopEndHead', 'AdminTopEndHead');#wymeditor
    $this->addHook('AdminFootEndBody', 'AdminFootEndBody');#wymeditor
   }
   if(strstr($_SERVER['PHP_SELF'],'medias.php'))//si medias.php 
    $this->addHook('AdminMediasFoot', 'AdminMediasFoot');#wymeditor medias manager js onclic return
  }
 }
 public function plxAdminEditArticleXml(){#Méthode qui supprime les <br /> lorsque les textareas sont laissé tel quel a l'enregistrement et a chaque fin de paragraphe, liste, ...
  echo '<?php '; ?>$xml = str_replace(array('[<br />]','<br /></'),array('[]','</'),$xml); ?><?php
 }
 public function plxAdminEditArticle(){#Méthode qui convertit les liens absolus en liens relatifs pour les medias, images et les documents?
  echo '<?php '; ?>
 if(isset($this->aConf['medias'])){// plx.5.4+
  $content['chapo'] = str_replace($this->racine.$this->aConf['medias'], $this->aConf['medias'], $content['chapo']);
  $content['content'] = str_replace($this->racine.$this->aConf['medias'], $this->aConf['medias'], $content['content']);
 }else{
  $content['chapo'] = str_replace(array($this->racine.$this->aConf['images'], $this->racine.$this->aConf['documents']), array($this->aConf['images'], $this->aConf['documents']), $content['chapo']);
  $content['content'] = str_replace(array($this->racine.$this->aConf['images'], $this->racine.$this->aConf['documents']), array($this->aConf['images'], $this->aConf['documents']), $content['content']);
 }
?><?php
  }
 public function AdminArticleTop(){#Méthode qui convertit les liens relatifs en liens absolus pour les medias, images et les documents?
  echo '<?php '; ?>
 if(isset($plxAdmin->aConf['medias'])){// plx.5.4+
  $chapo = str_replace($plxAdmin->aConf['medias'], $plxAdmin->racine.$plxAdmin->aConf['medias'], $chapo);
  $content = str_replace($plxAdmin->aConf['medias'], $plxAdmin->racine.$plxAdmin->aConf['medias'], $content);
 }else{
  $chapo = str_replace(array($plxAdmin->aConf['images'], $plxAdmin->aConf['documents']), array($plxAdmin->racine.$plxAdmin->aConf['images'], $plxAdmin->racine.$plxAdmin->aConf['documents']), $chapo);
  $content = str_replace(array($plxAdmin->aConf['images'], $plxAdmin->aConf['documents']), array($plxAdmin->racine.$plxAdmin->aConf['images'], $plxAdmin->racine.$plxAdmin->aConf['documents']), $content);
 }
?><?php
 }
 public function AdminTopEndHead(){#Insertion des dépendances js et css
  if(!file_exists(PLX_ROOT.'/core/lib/mediasManager.js'))#mediaManager
   echo '<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/mediasManager.js"></script>'.PHP_EOL;//FROM PLX 5.5
#dépendances & jquery
?>
  <link rel="stylesheet" type="text/css" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery/jquery.ui.resizable.css" />
  <link rel="stylesheet" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/skins/compact/skin.css">
  <link rel="stylesheet" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/skin.css">
  <script type="text/javascript">
   //typeof jQuery == 'undefined'
   !window.jQuery && document.write('<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery/jquery-3.2.1.min.js"><\/script>');
  </script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery/jquery-ui-1.12.1.custom.min.js"></script>
<!-- wymeditor et ses plugins -->
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/jquery.wymeditor.min.js"></script><!-- jquery.wymeditor.pack.js -->
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/hovertools/jquery.wymeditor.hovertools.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/resizable/jquery.wymeditor.resizable.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/fullscreen/jquery.wymeditor.fullscreen.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/table/jquery.wymeditor.table.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/embed/jquery.wymeditor.embed.js"></script>
<!--
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/tidy/jquery.wymeditor.tidy.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/list/jquery.wymeditor.list.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/rdfa/jquery.wymeditor.rdfa.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/structured_headings/jquery.wymeditor.structured_headings.js"></script>
-->
<?php
 }
 public function AdminFootEndBody(){#Insertion du script de gestion de Wymeditor
  // script de gestion dans PluXml
?>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/plugin.js"></script>
<script type="text/javascript">
  WEP.init("<?php echo PLX_PLUGINS.__CLASS__ ?>/", 
  ["table", "hovertools", "resizable", "fullscreen", "embed"],"fr","compact")
</script>';
<?php  //mediaManager
  if(!file_exists(PLX_ROOT.'/core/lib/mediasManager.js'))://FROM PLX 5.5
?>
<script type="text/javascript">
 mediasManager.construct({
  windowName : "<?php echo L_MEDIAS_TITLE ?>",
  racine: "<?php echo plxUtils::getRacine() ?>",
  urlManager: "core/admin/medias.php"
 });
</script>';
<?php endif;
 }
 public function AdminMediasFoot(){#changement des onclic target blank en lien retour de Wymeditor du gestionnaire des médias (popup)
?>
<script type="text/javascript">
if ((window.name == '<?php echo L_MEDIAS_TITLE ?>') || window.opener && window.opener.WEP){//if is media manager popup
 var tbody = document.getElementsByTagName('tbody');
 var ancres = tbody[0].getElementsByTagName('a');
 for (var i = 0; i < ancres.length; i++){
  if(ancres[i].getAttribute('onclick')){
   var str = ancres[i].getAttribute('onclick');
   var res = str.substr(0, 4);// this OR over[lay]
   if(res == 'this'){
    var type = 'document';
    if ((/\.(gif|jpg|jpeg|png)$/i).test(ancres[i].href))
     type = 'image';
    if (/\.(tb)\./i.test(ancres[i].href))
     type = 'thumb';
    if (/\.(mp3|ogg|wav)/i.test(ancres[i].href))
     type = 'audio';
    if (/\.(mp4|ogv|webm)/i.test(ancres[i].href))
     type = 'video';
    ancres[i].setAttribute('onclick','window.opener.WEP.insert(this.href,"'+ancres[i].title+'","'+type+'");window.close();return false;')
    ancres[i].style.color="green";
    ancres[i].title = "Ajouter "+ancres[i].title+" a l'article ("+type+").";
   }
  }
 }
}
</script>
<?php
 }
}

==> WymEditor.1.1.6.zip: WymEditor/WymEditor.php <==
<?php
/**
 * Plugin WymEditor for Pluxml
 *
 * @package	WymEditor
 * @version	1.1.6
 * @date	18.05.2019
 * @author	Thomas Ingles, sudwebdesign.free.fr
 **/
class WymEditor extends plxPlugin {
 public function __construct($default_lang){//var_dump(__CLASS__.'->'.__FUNCTION__.'() '.__FILE__.' : '.__LINE__);$e = new \Exception;var_dump($e->getTraceAsString());//exit(__LINE__.' '.__FILE__);
  parent::__construct($default_lang);
  if(defined('PLX_ADMIN')) {//Déclaration des hooks pour la zone d'administration
   if(strstr($_SERVER['PHP_SELF'],'article.php') || strstr($_SERVER['QUERY_STRING'],'plxMyShop&prod')){//edit art ou prod slmnt ::: strstr($_SERVER['PHP_SELF'],'statique.php') ||
    $this->addHook('plxAdminEditArticleXml', 'plxAdminEditArticleXml');
    $this->addHook('plxAdminEditArticle', 'plxAdminEditArticle');
    $this->addHook('AdminArticleTop', 'AdminArticleTop');

    $this->addHook('AdminTopEndHead', 'AdminTopEndHead');#wymeditor
    $this->addHook('AdminFootEndBody', 'AdminFootEndBody');#wymeditor
   }
   if(strstr($_SERVER['PHP_SELF'],'medias.php'))//si medias.php 
    $this->addHook('AdminMediasFoot', 'AdminMediasFoot');#wymeditor medias manager js onclic return
  }
 }
 public function plxAdminEditArticleXml(){#Méthode qui supprime les <br /> lorsque les textareas sont laissé tel quel a l'enregistrement et a chaque fin de paragraphe, liste, ...
  echo '<?php '; ?>$xml = str_replace(array('[<br />]','<br /></'),array('[]','</'),$xml); ?><?php
 }
 public function plxAdminEditArticle(){#Méthode qui convertit les liens absolus en liens relatifs pour les medias, images et les documents?
  echo '<?php '; ?>
 $d = '="';
 $s = "='";
 if(isset($this->aConf['medias'])){// plx.5.4+
  $c = array($d.$this->racine.$this->aConf['medias'],$s.$this->racine.$this->aConf['medias']);
  $r = array($d.$this->aConf['medias'],$s.$this->aConf['medias']);
 }else{
  $c = array($d.$this->racine.$this->aConf['images'],$s.$this->racine.$this->aConf['images'],$d.$this->racine.$this->aConf['documents'],$s.$this->racine.$this->aConf['documents']);
  $r = array($d.$this->aConf['images'],$s.$this->aConf['images'],$d.$this->aConf['documents'],$s.$this->aConf['documents']);
 }
 $content['chapo'] = str_replace($c,$r,$content['chapo']);
 $content['content'] = str_replace($c,$r,$content['content']);
?><?php
  }
 public function AdminArticleTop(){#Méthode qui convertit les liens relatifs en liens absolus pour l'affichage dans wym des medias, images et documents?
  echo '<?php '; ?>
 $d = '="';
 $s = "='";
 if(isset($plxAdmin->aConf['medias'])){// plx.5.4+
  $c = array($d.$plxAdmin->aConf['medias'],$s.$plxAdmin->aConf['medias']);
  $r = array($d.$plxAdmin->racine.$plxAdmin->aConf['medias'],$s.$plxAdmin->racine.$plxAdmin->aConf['medias']);
 }else{
  $c = array($d.$plxAdmin->aConf['images'],$s.$plxAdmin->aConf['images'],$d.$plxAdmin->aConf['documents'],$s.$plxAdmin->aConf['documents']);
  $r = array($d.$plxAdmin->racine.$plxAdmin->aConf['images'],$s.$plxAdmin->racine.$plxAdmin->aConf['images'],$d.$plxAdmin->racine.$plxAdmin->aConf['documents'],$s.$plxAdmin->racine.$plxAdmin->aConf['documents']);
 }
 $chapo = str_replace($c,$r,$chapo);
 $content = str_replace($c,$r,$content);
?><?php
 }
 public function AdminTopEndHead(){#Insertion des dépendances js et css
  if(!file_exists(PLX_ROOT.'/core/lib/mediasManager.js'))#mediaManager
   echo '<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/mediasManager.js"></script>'.PHP_EOL;//FROM PLX 5.5
#dépendances & jquery
?>
  <link rel="stylesheet" type="text/css" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery/jquery.ui.resizable.css" />
  <link rel="stylesheet" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/skins/compact-large/skin.css">
  <link rel="stylesheet" href="<?php echo PLX_PLUGINS.__CLASS__ ?>/skin.css">
  <script type="text/javascript">
   //typeof jQuery == 'undefined'
   !window.jQuery && document.write('<script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery/jquery-3.3.1.min.js"><\/script>');
  </script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/jquery/jquery-ui-1.12.1.custom.min.js"></script>
<!-- wymeditor et ses plugins -->
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/jquery.wymeditor.min.js"></script><!-- jquery.wymeditor.pack.js -->
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/hovertools/jquery.wymeditor.hovertools.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/resizable/jquery.wymeditor.resizable.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/fullscreen/jquery.wymeditor.fullscreen.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/table/jquery.wymeditor.table.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/embed/jquery.wymeditor.embed.js"></script>
<!--
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/structured_headings/jquery.wymeditor.structured_headings.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/tidy/jquery.wymeditor.tidy.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/rdfa/jquery.wymeditor.rdfa.js"></script>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/wymeditor/plugins/list/jquery.wymeditor.list.js"></script>
-->
<?php
 }
 public function AdminFootEndBody(){#Insertion du script de gestion de Wymeditor
  // script de gestion dans PluXml
?>
  <script type="text/javascript" src="<?php echo PLX_PLUGINS.__CLASS__ ?>/plugin.js"></script>
<script type="text/javascript">
  var fromEditor = false;//Fix window.opener image d'accroche
  WEP.init("<?php echo PLX_PLUGINS.__CLASS__ ?>/", 
  ["table", "hovertools", "resizable", "fullscreen", "embed"],"fr","compact");
</script>

<?php  //mediaManager
  if(!file_exists(PLX_ROOT.'/core/lib/mediasManager.js'))://FROM PLX 5.5
?>
<script type="text/javascript">
 mediasManager.construct({
  windowName : "<?php echo L_MEDIAS_TITLE.'_'.__CLASS__ ?>",
  racine: "<?php echo plxUtils::getRacine() ?>",
  urlManager: "core/admin/medias.php"
 });
</script>';
<?php endif;
 }
 public function AdminMediasFoot(){#changement des onclic target blank en lien retour de Wymeditor du gestionnaire des médias (popup)
?>
<script type="text/javascript">
if ((window.name == '<?php echo L_MEDIAS_TITLE.'_'.__CLASS__ ?>') || window.opener.fromEditor && window.opener.WEP){//if is media manager popup
 var tbody = document.getElementsByTagName('tbody');
 var ancres = tbody[0].getElementsByTagName('a');
 for (var i = 0; i < ancres.length; i++){
  if(ancres[i].getAttribute('onclick')){
   var str = ancres[i].getAttribute('onclick');
   var res = str.substr(0, 4);// this OR over[lay]
   if(res == 'this'){
    var type = 'document';
    if ((/\.(gif|jpg|jpeg|png)$/i).test(ancres[i].href))
     type = 'image';
    if (/\.(tb)\./i.test(ancres[i].href))
     type = 'thumb';
    if (/\.(mp3|ogg|wav)/i.test(ancres[i].href))
     type = 'audio';
    if (/\.(mp4|ogv|webm)/i.test(ancres[i].href))
     type = 'video';
    ancres[i].setAttribute('onclick','window.opener.WEP.insert(this.href,"'+ancres[i].title+'","'+type+'");window.close();return false;')
    ancres[i].style.color="green";
    ancres[i].title = "Ajouter "+ancres[i].title+" a l'article ("+type+").";
   }
  }
 }
}
</script>
<?php
 }
}
